/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.enums;

import java.util.HashMap;

import com.redhat.rhevm.api.model.LogSeverity;

public enum PowerShellLogSeverity {
    NORMAL(0), WARNING(1), ERROR(2), ALERT(10);

    private static HashMap<Integer, PowerShellLogSeverity> mapping;
    static {
        mapping = new HashMap<Integer, PowerShellLogSeverity>();
        for (PowerShellLogSeverity value : values()) {
            mapping.put(value.value, value);
        }
    }

    private int value;

    private PowerShellLogSeverity(int value) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    public LogSeverity map() {
        switch (this) {
        case NORMAL:
            return LogSeverity.NORMAL;
        case WARNING:
            return LogSeverity.WARNING;
        case ERROR:
            return LogSeverity.ERROR;
        case ALERT:
            return LogSeverity.ALERT;
        default:
            assert false : this;
            return null;
        }
    }

    public static PowerShellLogSeverity forValue(int value) {
        return mapping.get(value);
    }
}
