/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.enums;

import java.util.HashMap;

import com.redhat.rhevm.api.model.NetworkStatus;

public enum PowerShellNetworkStatus {
    NonOperational(0), Operational(1);

    private static HashMap<Integer, PowerShellNetworkStatus> mapping;
    static {
        mapping = new HashMap<Integer, PowerShellNetworkStatus>();
        for (PowerShellNetworkStatus value : values()) {
            mapping.put(value.value, value);
        }
    }

    private int value;

    private PowerShellNetworkStatus(int value) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    public NetworkStatus map() {
        switch (this) {
        case NonOperational:
            return NetworkStatus.NON_OPERATIONAL;
        case Operational:
            return NetworkStatus.OPERATIONAL;
        default:
            assert false : this;
            return null;
        }
    }

    public static PowerShellNetworkStatus forValue(int value) {
        return mapping.get(value);
    }
}
