/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.Cluster;
import com.redhat.rhevm.api.model.CPU;
import com.redhat.rhevm.api.model.DataCenter;
import com.redhat.rhevm.api.model.MemoryPolicy;
import com.redhat.rhevm.api.model.MemoryOverCommit;
import com.redhat.rhevm.api.model.SchedulingPolicy;
import com.redhat.rhevm.api.model.SchedulingPolicyThresholds;
import com.redhat.rhevm.api.model.SchedulingPolicyType;
import com.redhat.rhevm.api.model.Version;
import com.redhat.rhevm.api.powershell.enums.PowerShellHostSelectionAlgorithm;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellCluster {

    protected static SchedulingPolicy parseSchedulingPolicy(PowerShellParser.Entity entity) {
        SchedulingPolicyType type = entity.get("selectionalgorithm", PowerShellHostSelectionAlgorithm.class).map();

        if (type == null) {
            return null;
        }

        int low = entity.get("lowutilization", Integer.class);
        int high = entity.get("highutilization", Integer.class);
        int duration = entity.get("cpuovercommitdurationminutes", Integer.class) * 60;

        SchedulingPolicy policy = new SchedulingPolicy();
        policy.setPolicy(type.value());
        policy.setThresholds(new SchedulingPolicyThresholds());

        switch (type) {
        case POWER_SAVING:
            policy.getThresholds().setLow(low);
        case EVENLY_DISTRIBUTED:
            policy.getThresholds().setHigh(high);
            policy.getThresholds().setDuration(duration);
            break;
        default:
            break;
        }

        return policy;
    }

    public static List<Cluster> parse(PowerShellParser parser, String output) {
        List<Cluster> ret = new ArrayList<Cluster>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            Cluster cluster = new Cluster();

            cluster.setId(entity.get("clusterid", String.class, Integer.class).toString());
            cluster.setName(entity.get("name"));
            cluster.setDescription(entity.get("description"));

            cluster.setMemoryPolicy(new MemoryPolicy());
            cluster.getMemoryPolicy().setOverCommit(new MemoryOverCommit());
            cluster.getMemoryPolicy().getOverCommit().setPercent(entity.get("maxhostmemoryovercommit", Integer.class));

            cluster.setSchedulingPolicy(parseSchedulingPolicy(entity));

            cluster.setVersion(entity.get("compatibilityversion", Version.class));

            CPU cpu = new CPU();
            cpu.setId(entity.get("cpuname"));
            cluster.setCpu(cpu);

            DataCenter dataCenter = new DataCenter();
            dataCenter.setId(entity.get("datacenterid"));
            cluster.setDataCenter(dataCenter);

            ret.add(cluster);
        }

        return ret;
    }
}
