/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.User;
import com.redhat.rhevm.api.model.Group;
import com.redhat.rhevm.api.model.Groups;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellUser {

    private static String TYPE = "RhevmCmd.CLIUser";

    public static List<User> parse(PowerShellParser parser, String output) {
        List<User> ret = new ArrayList<User>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            if (TYPE.equals(entity.getType())) {
                User user = new User();
                user.setId(entity.get("userid"));
                user.setName(entity.get("name"));
                user.setDepartment(entity.get("department"));
                user.setEmail(entity.get("email"));
                user.setLastName(entity.get("lastname"));
                user.setUserName(entity.get("username"));
                parseGroups(user, entity.get("groups", List.class));
                ret.add(user);
            }
        }

        return ret;
    }

    @SuppressWarnings("unchecked")
    private static void parseGroups(User user, List groups) {
        if (!(groups == null || groups.isEmpty())) {
             user.setGroups(new Groups());
             for (String name : (List<String>)groups) {
                 Group group = new Group();
                 group.setName(name);
                 user.getGroups().getGroups().add(group);
             }
        }
    }
}
