/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import javax.ws.rs.core.UriInfo;

import com.redhat.rhevm.api.common.resource.AbstractUpdatableResource;
import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.common.util.ReapedMap;
import com.redhat.rhevm.api.model.BaseResource;
import com.redhat.rhevm.api.model.Link;

public abstract class AbstractPowerShellCollectionResource<R extends BaseResource,
                                                           U extends AbstractUpdatableResource<R>>
    extends InjectableUriProviderBase {

    private ReapedMap<String, U> resources;

    public AbstractPowerShellCollectionResource() {
        resources = new ReapedMap<String, U>();
    }

    protected U getSubResource(String id) {
        synchronized (resources) {
            U ret = resources.get(id);
            if (ret == null) {
                ret = createSubResource(id);
                resources.put(id, ret);
                resources.reapable(id);
            }
            return ret;
        }
    }

    protected void removeSubResource(String id) {
        synchronized (resources) {
            resources.remove(id);
        }
    }

    protected abstract U createSubResource(String id);

    protected R addStatus(UriInfo uriInfo, R model, String taskIds) {
        if (taskIds != null) {
            Link link = new Link();
            link.setRel(CREATION_STATUS);
            link.setHref(LinkHelper.getUriBuilder(uriInfo, model).path(CREATION_STATUS).path(taskIds).build().toString());
            model.getLinks().add(link);
        }
        return model;
    }

}
