/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.net.URLEncoder;
import java.util.concurrent.Executor;

import javax.ws.rs.core.UriBuilder;
import javax.ws.rs.core.UriInfo;

import com.redhat.rhevm.api.model.Creation;
import com.redhat.rhevm.api.resource.CreationResource;
import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.powershell.model.PowerShellAsyncTask;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;

import static com.redhat.rhevm.api.common.util.LinkHelper.combine;

public class PowerShellCreationResource extends AbstractPowerShellActionableResource<Creation> implements CreationResource {

    private String ids;

    public PowerShellCreationResource(String ids,
                                      Executor executor,
                                      UriInfoProvider uriProvider,
                                      PowerShellPoolMap shellPools,
                                      PowerShellParser parser) {
        super(PowerShellAsyncTask.parseTaskIds(ids)[0], executor, uriProvider, shellPools, parser);
        this.ids = ids;
    }

    public Creation runAndParseSingle(String command) {
        return PowerShellAsyncTask.parse(getParser(), PowerShellCmd.runCommand(getPool(), command));
    }

    public Creation addLinks(Creation creation) {
        // we avoid using the LinkHelper as the CreationResource does not
        // follow the usual pattern of collection and sub-resource
        creation.setHref(UriBuilder.fromPath(getPath(getUriInfo())).build().toString());
        return creation;
    }

    @Override
    public Creation get() {
        return addLinks(runAndParseSingle("get-tasksstatus -commandtasksids " + ids));
    }

    private String getPath(UriInfo uriInfo) {
        StringBuilder path = new StringBuilder();
        // avoid encoding forward slashes to keep URI looking consistent
        for (String p : uriInfo.getPath().split("/")) {
            (path.length() == 0 ? path : path.append("/")).append(URLEncoder.encode(p));
        }
        return combine(uriInfo.getBaseUri().getPath(), path.toString());
    }
}
