/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.CdRom;
import com.redhat.rhevm.api.model.CdRoms;
import com.redhat.rhevm.api.model.File;
import com.redhat.rhevm.api.model.VM;
import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.resource.ReadOnlyDevicesResource;


public class PowerShellReadOnlyCdRomsResource extends AbstractPowerShellDevicesResource<CdRom, CdRoms> implements ReadOnlyDevicesResource<CdRom, CdRoms> {

    private static final String CDROM_ID = Integer.toString("cdrom".hashCode());

    private CdRomQuery query;

    public PowerShellReadOnlyCdRomsResource(String parentId, PowerShellPoolMap shellPools, CdRomQuery query, UriInfoProvider uriProvider) {
        super(parentId, shellPools, uriProvider);
        this.query = query;
    }

    protected CdRom buildCdRom(String cdIsoPath) {
        CdRom cdrom = new CdRom();
        cdrom.setId(CDROM_ID);
        if (cdIsoPath != null) {
            cdrom.setFile(new File());
            cdrom.getFile().setId(cdIsoPath);
        }
        cdrom.setVm(new VM());
        cdrom.getVm().setId(parentId);
        return addLinks(cdrom);
    }

    @Override
    public List<CdRom> getDevices() {
        List<CdRom> cdroms = new ArrayList<CdRom>();
        cdroms.add(buildCdRom(query.getCdIsoPath()));
        return cdroms;
    }

    @Override
    public CdRom addLinks(CdRom cdrom) {
        return LinkHelper.addLinks(getUriInfo(), cdrom);
    }

    @Override
    public CdRoms list() {
        CdRoms cdroms = new CdRoms();
        for (CdRom cdrom : getDevices()) {
            cdroms.getCdRoms().add(addLinks(cdrom));
        }
        return cdroms;
    }

    @Override
    public PowerShellReadOnlyDeviceResource<CdRom, CdRoms> getDeviceSubResource(String id) {
        return new PowerShellReadOnlyDeviceResource<CdRom, CdRoms>(this, id);
    }

    public static abstract class CdRomQuery {
        protected String id;
        public CdRomQuery(String id) {
            this.id = id;
        }
        protected abstract String getCdIsoPath();
    }
}
