/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.List;

import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriBuilder;

import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.model.Tag;
import com.redhat.rhevm.api.model.Tags;
import com.redhat.rhevm.api.resource.TagResource;
import com.redhat.rhevm.api.resource.TagsResource;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;

import static com.redhat.rhevm.api.common.util.CompletenessAssertor.validateParameters;

public class PowerShellTagsResource
    extends AbstractPowerShellCollectionResource<Tag, PowerShellTagResource>
    implements TagsResource {

    public List<Tag> runAndParse(String command) {
        return PowerShellTagResource.runAndParse(getPool(), getParser(), command);
    }

    public Tag runAndParseSingle(String command) {
        return PowerShellTagResource.runAndParseSingle(getPool(), getParser(), command);
    }

    @Override
    public Tags list() {
        StringBuilder buf = new StringBuilder();

        buf.append("$tags = @(); ");
        buf.append("$tags += get-tag -1; ");
        buf.append("$tags += get-tags; ");
        buf.append("$tags");

        Tags ret = new Tags();
        for (Tag tag : runAndParse(buf.toString())) {
            ret.getTags().add(LinkHelper.addLinks(getUriInfo(), tag));
        }
        return ret;
    }

    @Override
    public Response add(Tag tag) {
        validateParameters(tag, "name");

        String parentId = null;
        String parentName = null;
        if (tag.isSetParent() && tag.getParent().isSetTag()) {
            if (tag.getParent().getTag().isSetId()) {
                parentId = tag.getParent().getTag().getId();
            } else if (tag.getParent().getTag().isSetName()) {
                parentName = tag.getParent().getTag().getName();
            }
        }

        StringBuilder buf = new StringBuilder();

        if (parentId != null) {
            buf.append("$parent = get-tag " + PowerShellUtils.escape(parentId) + "; ");
        } else if (parentName != null) {
            buf.append("$parent = get-tags | ? { $_.name -eq " + PowerShellUtils.escape(parentName) + " }; ");
        }

        buf.append("add-tag");
        buf.append(" -name " + PowerShellUtils.escape(tag.getName()));
        if (tag.isSetDescription()) {
            buf.append(" -description " + PowerShellUtils.escape(tag.getDescription()));
        }

        if (parentId != null || parentName != null) {
            buf.append(" -parenttagobject $parent");
        }

        tag = LinkHelper.addLinks(getUriInfo(), runAndParseSingle(buf.toString()));

        UriBuilder uriBuilder = getUriInfo().getAbsolutePathBuilder().path(tag.getId());

        return Response.created(uriBuilder.build()).entity(tag).build();
    }

    @Override
    public void remove(String id) {
        PowerShellCmd.runCommand(getPool(), "remove-tag -tagid " + PowerShellUtils.escape(id));
        removeSubResource(id);
    }

    @Override
    public TagResource getTagSubResource(String id) {
        return getSubResource(id);
    }

    protected PowerShellTagResource createSubResource(String id) {
        return new PowerShellTagResource(id, getExecutor(), this, shellPools, getParser());
    }
}
